/**
 * This event is created when a user requests to load or save a file
 * from WebsaverDialogLoad or WebsaverDialogSave.
 */
public class WebsaverDialogEvent
{
    private String filename, password;
    private WebsaverConnection source;
    /**
     * Create a WebsaverDialogEvent, given its connection and the filename to load or save.
     * Note that loading versus saving is unimportant because the event will only be
     * dispatched to the correct method, anyway.
     */

    public WebsaverDialogEvent (WebsaverConnection wsConn)
    {
	this(wsConn, null, null);
    }

    public WebsaverDialogEvent (WebsaverConnection wsConn, String filename)
    {
	this(wsConn, filename, null);
    }

    /**
     * Create a WebsaverDialogEvent, given its connection and the filename to load or save, 
     * as well as a password.
     */
    public WebsaverDialogEvent (WebsaverConnection wsConn, String filename, String password)
    {
	this.source = wsConn;
	this.filename = filename;
	this.password = password;
    }

    /**
     * Return the WebsaverConnection the load/save request took place on.
     */
    public WebsaverConnection getSource ()
    {
	return source;
    }

    /**
     * Return the filename to be loaded/saved
     */
    public String getFilename ()
    {
	return filename;
    }

    /**
     * Return the password for the associated file.
     */
    public String getPassword ()
    {
	return password;
    }
}
