import java.awt.*;
import java.awt.event.*;
import java.util.Vector;
import java.util.Hashtable;

/** WebsaverDialogLoad.java
 *
 *  @author Brad Fitzpatrick, bradfitz@bradfitz.com
 */
public class WebsaverDialogLoad extends Frame implements ActionListener, WindowListener 
{
    private Button btnLoad = new Button("Load");
    private Button btnRefresh = new Button("Refresh");
    private TextField txtPassword = new TextField(10);
    boolean showPassword;
    private List lstFiles = new List();
    private WebsaverConnection wsConn;
    private Vector listeners;

    public WebsaverDialogLoad (WebsaverConnection conn)
    {
	this(conn, false);
    }

    public WebsaverDialogLoad (WebsaverConnection conn, boolean showPassword)
    {
	super("Load File");

	txtPassword.setEchoChar('*');
	this.wsConn = conn;
	this.showPassword = showPassword;
	listeners = new Vector();
	
	Panel buttonPanel = new Panel();
	buttonPanel.setLayout(new FlowLayout());
	buttonPanel.add(btnLoad);
	buttonPanel.add(btnRefresh);
	if (showPassword) {
	    buttonPanel.add(new Label("Password, if any:"));
	    buttonPanel.add(txtPassword);
	}
	add("South", buttonPanel);
	add("Center", lstFiles);

	btnLoad.addActionListener(this);
	btnRefresh.addActionListener(this);
	addWindowListener(this);

	refreshList();
    }

    /** Shows the Dialog, centered over component cpt. */
    public void showDialog (Component cpt)
    {
	// parent location and dimension
	Dimension pd = cpt.getSize();
	Point pl = cpt.getLocationOnScreen();

	// this dimension and location
	Dimension td = new Dimension(400, 200);
	Point tl = new Point(pl.x + (pd.width-td.width)/2, pl.y + (pd.height-td.height)/2);

	setSize(td);
	setLocation(tl);

	setVisible(true);
	toFront();
    }

    /** Hides the dialog */
    public void hideDialog ()
    {
	setVisible(false);
    }

    /** Call this to register a listener for when somebody presses Load */
    public void addWebsaverDialogListener (WebsaverDialogListener wdl)
    {
	listeners.addElement(wdl);
    }

    public void actionPerformed(ActionEvent evt)
    {
	Object source = evt.getSource();
	if ((Button)source == btnLoad) {
	    String sel = lstFiles.getSelectedItem();
	    if (sel != null) {
		// dispatch events!
		for (int i=0; i<listeners.size(); i++) {
		    WebsaverDialogListener wdl = (WebsaverDialogListener) listeners.elementAt(i);
		    WebsaverDialogEvent wde = new WebsaverDialogEvent(wsConn, sel, showPassword ? txtPassword.getText() : null);
		    wdl.websaverFileLoad(wde);
		}
	    }
	} // end btnLoad
	else if ((Button)source == btnRefresh) {
	    refreshList();
	}
    }

    public void refreshList ()
    {
	Hashtable req = new Hashtable();
	req.put("mode", "listfiles");

	lstFiles.removeAll();
	try {
	    Hashtable res = wsConn.sendRequest(req);
	    int filecount = (new Integer((String) res.get("filecount"))).intValue();
	    for (int i=0; i<filecount; i++) {
		lstFiles.add((String) res.get("f" + i));
	    }
	} catch (Exception e) { }
    }

    public void windowOpened(WindowEvent e)
    {
    }

    public void windowClosing(WindowEvent e)
    {
	setVisible(false);
    }

    public void windowClosed(WindowEvent e)
    {
    }

    public void windowIconified(WindowEvent e)
    {
    }

    public void windowDeiconified(WindowEvent e)
    {
    }

    public void windowActivated(WindowEvent e)
    {
    }

    public void windowDeactivated(WindowEvent e)
    {
    }

}
